AndroidDeeplink class

A deep link in a Android build of a Flutter project.

The deeplink is defined in intent filters of AndroidManifest.xml in the Android sub-project.

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String?
The host section of the deeplink.
final
intentFilterChecks → IntentFilterChecks
The intent filter checks section of the deeplink.
final
path → String
The path pattern section of the deeplink.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
The scheme section of the deeplink.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited