IntentFilterChecks class

Intent filter checks for a deep link.

The intent filters are from AndroidManifest.xml in the Android sub-project.

Properties

hasActionView → bool
final
hasAutoVerify → bool
final
hasBrowsableCategory → bool
final
hasDefaultCategory → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited