DeeplinkManager class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAndroidAppLinkSettings({required String rootPath, required String buildVariant, String? ide, bool suppressAnalytics = false})
→ Future<Map<String, Object?>>
-
-
getAndroidBuildVariants({required String rootPath, String? ide, bool suppressAnalytics = false})
→ Future<Map<String, Object?>>
-
-
getFlutterBinary()
→ String
-
-
getIosBuildOptions({required String rootPath, String? ide, bool suppressAnalytics = false})
→ Future<Map<String, Object?>>
-
-
getIosUniversalLinkSettings({required String rootPath, required String configuration, required String target, String? ide, bool suppressAnalytics = false})
→ Future<Map<String, Object?>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
runProcess(String executable, {required List<String> arguments, String? ide, bool suppressAnalytics = false})
→ Future<ProcessResult>
-
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
kErrorField
→ const String
-
The key to retrieve error message from the returning map of this class's
APIs.
-
kOutputJsonField
→ const String
-
The key to retrieve output json from the returning map of this class's
APIs.