DevToolsExtensionConfig class

Describes an extension that can be dynamically loaded into a custom screen in DevTools.

Implemented types

Constructors

DevToolsExtensionConfig.parse(Map<String, Object?> json)
factory

Properties

analyticsSafeName → String
no setter
detectedFromStaticContext → bool
Whether this extension was detected from a static context.
final
devtoolsOptionsUri → String
The file:// URI to the devtools_options.yaml file that this extension's enabled state will be stored at.
final
displayName → String
no setter
extensionAssetsPath → String
The absolute path to this extension's assets on disk.
final
hashCode → int
The hash code for this object.
no setteroverride
identifier → String
no setter
isPubliclyHosted → bool
Whether this extension is distrubuted in a public package on pub.dev.
final
The link to the issue tracker for this DevTools extension.
final
materialIconCodePoint → int
The code point for the material icon that will parsed by Flutter's IconData class for displaying in DevTools.
final
name → String
The package name that this extension is for.
final
requiresConnection → bool
Whether this extension requires a connected app to use.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
The version for the DevTools extension.
final

Methods

compareTo(DevToolsExtensionConfig other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override