DevToolsStoreKeys enum

Inheritance
Available extensions

Values

lastReleaseNotesVersion → const DevToolsStoreKeys

The key holding the value for the last DevTools version that the user viewed release notes for.

surveyActionTaken → const DevToolsStoreKeys

The key holding the value for whether the user has taken action on the DevTools survey prompt.

surveyShownCount → const DevToolsStoreKeys

The key holding the value for number of times the user has seen the DevTools survey prompt without taking action.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DevToolsStoreKeys>
A constant List of the values in this enum, in order of their declaration.