DevToolsUsage class

Provides access to the local DevTools store (~/.flutter-devtools/.devtools).

Constructors

DevToolsUsage()

Properties

activeSurvey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastReleaseNotesVersion ↔ String
getter/setter pair
properties ↔ IOPersistentProperties
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surveyActionTaken ↔ bool
getter/setter pair
surveyShownCount → int
no setter

Methods

incrementSurveyShownCount() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rewriteActiveSurvey(bool actionTaken, int shownCount) → void
Need to rewrite the entire survey structure for property to be persisted.
surveyNameExists(String surveyName) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

storeName → const String