fileSystem top-level constant
FileSystem
const fileSystem
The real, local file system, which can be avoided in tests.
Implementation
const FileSystem fileSystem = LocalFileSystem();
The real, local file system, which can be avoided in tests.
const FileSystem fileSystem = LocalFileSystem();