AppFixture class

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
isolates → List<IsolateRef?>
final
lines → Stream<String>
final
mainIsolate → IsolateRef?
no setter
onAppStarted → Future<void>
no setter
onTeardown → Future<void> Function()?
final
process → Process
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceConnection → VmService
final
serviceUri → Uri
final

Methods

invoke(String expression) → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
teardown() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited