Chrome class

Properties

executable → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({String? url, int debugPort = 9222}) → Future<ChromeProcess>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(String executable) → Chrome?
getCreateChromeDataDir() → String
Return the path to a per-user Chrome data dir.
locate() → Chrome?