ChromeProcess class

Constructors

ChromeProcess(Process process, int debugPort)

Properties

debugPort → int
final
hashCode → int
The hash code for this object.
no setterinherited
isAlive → bool
no setter
onExit → Future<int>
no setter
process → Process
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connectToTab(String url, {Duration timeout = const Duration(seconds: 20)}) → Future<ChromeTab?>
connectToTabId(String host, String id, {Duration timeout = const Duration(seconds: 20)}) → Future<ChromeTab?>
getFirstTab({Duration timeout = const Duration(seconds: 20)}) → Future<ChromeTab?>
kill() → bool
Returns true if the signal is successfully delivered to the process. Otherwise the signal could not be sent, usually meaning that the process is already dead.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited