ChromeTab class

Constructors

ChromeTab(ChromeTab wipTab)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setter
onConsoleAPICalled → Stream<ConsoleAPIEvent>
no setter
onDisconnect → Stream<void>
no setter
onExceptionThrown → Stream<ExceptionThrownEvent>
no setter
onLogEntryAdded → Stream<LogEntry>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wipConnection → WipConnection?
no setter
wipTab → ChromeTab
final

Methods

connect({bool verbose = false}) → Future<WipConnection?>
createNewTarget() → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<WipResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited