CliAppFixture class

Inheritance

Properties

appScriptPath → String
final
hashCode → int
The hash code for this object.
no setterinherited
isolates → List<IsolateRef?>
finalinherited
lines → Stream<String>
finalinherited
mainIsolate → IsolateRef?
no setterinherited
onAppStarted → Future<void>
no setterinherited
onTeardown → Future<void> Function()?
finalinherited
process → Process
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptSource → String
no setter
serviceConnection → VmService
finalinherited
serviceUri → Uri
finalinherited

Methods

invoke(String expression) → Future<Response>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
teardown() → Future<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String appScriptPath) → Future<CliAppFixture>
parseBreakpointLines(String source) → List<int>
parseExceptionLines(String source) → List<int>
parseSteppingLines(String source) → List<int>