IOMixin mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderrController → StreamController<String>
final
stdoutController → StreamController<String>
final
streamSubscriptions → List<StreamSubscription<String>>
final

Methods

cancelAllStreamSubscriptions() → Future<void>
killForcefully(Process process, {bool debugLogging = false}) → Future<int>
killGracefully(Process process, {bool debugLogging = false}) → Future<int>
listenToProcessOutput(Process process, {void onStdout(String)?, void onStderr(String)?, void printCallback(String)?, String printTag = ''}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

killTimeout → const Duration