IntegrationTestRunner class

Mixed-in types

Constructors

IntegrationTestRunner()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderrController → StreamController<String>
finalinherited
stdoutController → StreamController<String>
finalinherited
streamSubscriptions → List<StreamSubscription<String>>
finalinherited

Methods

cancelAllStreamSubscriptions() → Future<void>
inherited
killForcefully(Process process, {bool debugLogging = false}) → Future<int>
inherited
killGracefully(Process process, {bool debugLogging = false}) → Future<int>
inherited
listenToProcessOutput(Process process, {void onStdout(String)?, void onStderr(String)?, void printCallback(String)?, String printTag = ''}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String testTarget, {required String testDriver, bool headless = false, bool useWasm = false, List<String> dartDefineArgs = const <String>[], bool debugLogging = false}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited