useWasm property
bool
get
useWasm
Whether this integration test should be run against dart2wasm-compiled DevTools.
Implementation
bool get useWasm => argResults.flag(_wasmArg);
Whether this integration test should be run against dart2wasm-compiled DevTools.
bool get useWasm => argResults.flag(_wasmArg);